@@ -134,7 +134,7 @@ class superplt():
                   Label=['normal', 'normal'], Capsize=3, FMT='-o', MS=5,
                   datagraphname=None, canvascolor='white', backcolor='white',
                   text=True, fitcolor=(0.1, 0.1, 0.1, 0.9), datacolor='black', 
-                  DPI=None, FIGSIZE=None, fit=True, manualmaxminY=None):
+                  DPI=None, FIGSIZE=None, fit=True, manualmaxminY=None, textunit=['', '']):
 
 
         """
@@ -235,8 +235,8 @@ class superplt():
                         thirdposy = minY + 0.76 * (maxY - minY)
                         fourthposy = minY + 0.69 * (maxY - minY)
                         ax.text(minx, firstposy, r'$y=ax+b$', fontsize=10)
-                        ax.text(minx, secondposy, 'a={:.2uP}'.format(relation.slope), fontsize=10)
-                        ax.text(minx, thirdposy, 'b={:.2uP}'.format(relation.intercept), fontsize=10)
+                        ax.text(minx, secondposy, 'a={:.2uP}'.format(relation.slope) + ' ' + textunit[0], fontsize=10)
+                        ax.text(minx, thirdposy, 'b={:.2uP}'.format(relation.intercept) + ' ' + textunit[1], fontsize=10)
                         ax.text(minx, fourthposy, '$R^2$={:.3f}'.format(relation.R2), fontsize=10)
                     else:  # 범례가 왼쪽일 때
                         firstposy = minY + 0.31 * (maxY - minY)
@@ -244,8 +244,8 @@ class superplt():
                         thirdposy = minY + 0.17 * (maxY - minY)
                         fourthposy = minY + 0.1 * (maxY - minY)
                         ax.text(posx, firstposy, r'$y=ax+b$', fontsize=10)
-                        ax.text(posx, secondposy, 'a={:.2uP}'.format(relation.slope), fontsize=10)
-                        ax.text(posx, thirdposy, 'b={:.2uP}'.format(relation.intercept), fontsize=10)
+                        ax.text(posx, secondposy, 'a={:.2uP}'.format(relation.slope) + ' ' + textunit[0], fontsize=10)
+                        ax.text(posx, thirdposy, 'b={:.2uP}'.format(relation.intercept) + ' ' + textunit[1], fontsize=10)
                         ax.text(minx, fourthposy, '$R^2$={:.3f}'.format(relation.R2), fontsize=10)
                 else:  # 기울기가 음수일 때
                     if pos_leg == 'right':  # 범례가 오른쪽일 때
@@ -254,8 +254,8 @@ class superplt():
                         thirdposy = minY + 0.17 * (maxY - minY)
                         fourthposy = minY + 0.1 * (maxY - minY)
                         ax.text(minx, firstposy, r'$y=ax+b$', fontsize=10)
-                        ax.text(minx, secondposy, 'a={:.2uP}'.format(relation.slope), fontsize=10)
-                        ax.text(minx, thirdposy, 'b={:.2uP}'.format(relation.intercept), fontsize=10)
+                        ax.text(minx, secondposy, 'a={:.2uP}'.format(relation.slope) + ' ' + textunit[0], fontsize=10)
+                        ax.text(minx, thirdposy, 'b={:.2uP}'.format(relation.intercept) + ' ' + textunit[1], fontsize=10)
                         ax.text(minx, fourthposy, '$R^2$={:.3f}'.format(relation.R2), fontsize=10)
                     else:  # 범례가 왼쪽일 때
                         firstposy = minY + 0.9 * (maxY - minY)
@@ -263,8 +263,8 @@ class superplt():
                         thirdposy = minY + 0.76 * (maxY - minY)
                         fourthposy = minY + 0.69 * (maxY - minY)
                         ax.text(posx, firstposy, r'$y=ax+b$', fontsize=10)
-                        ax.text(posx, secondposy, 'a={:.2uP}'.format(relation.slope), fontsize=10)
-                        ax.text(posx, thirdposy, 'b={:.2uP}'.format(relation.intercept), fontsize=10)
+                        ax.text(posx, secondposy, 'a={:.2uP}'.format(relation.slope) + ' ' + textunit[0], fontsize=10)
+                        ax.text(posx, thirdposy, 'b={:.2uP}'.format(relation.intercept) + ' ' + textunit[1], fontsize=10)
                         ax.text(minx, fourthposy, '$R^2$={:.3f}'.format(relation.R2), fontsize=10)
 
         # Xlabel 작성
