@@ -2,22 +2,17 @@ import os
 import subprocess
 import platform
 
-if platform.system() == 'Windows':
-    Directory = __file__.replace("\\exp.py", "")
-    FILEBROWSER_PATH = os.path.join(os.getenv('WINDIR'), 'explorer.exe')
-else:
-    Directory = __file__.replace('/exp.py', '')
-
 
 def Shvar_open():
     if platform.system() == 'Windows':
-        Directory = __file__.replace("\\exp.py", "")
+        FILEBROWSER_PATH = os.path.join(os.getenv('WINDIR'), 'explorer.exe')
+        Directory = __file__.replace("\\explorer.py", "")
         path = os.path.normpath(Directory)
         if os.path.isdir(path):
             subprocess.run([FILEBROWSER_PATH, path])
         elif os.path.isfile(path):
             subprocess.run([FILEBROWSER_PATH, '/select,', os.path.normpath(path)])
     else:
-        Directory = __file__.replace('/exp.py', '')
+        Directory = __file__.replace('/explorer.py', '')
         print("If OS is not Window, this function is not available")
         print("PATH : " + Directory)
